.. _api_engine:

flameiq.engine — Statistical Engine
=====================================

Statistics
----------

.. automodule:: flameiq.engine.statistics
   :members:

Baseline Strategies
-------------------

.. automodule:: flameiq.engine.baseline
   :members:
